NmeaSentences

Struct NmeaSentences 

pub struct NmeaSentences {
    pub gga: bool,
    pub gll: bool,
    pub gsa: bool,
    pub gsv: bool,
    pub rmc: bool,
    pub vtg: bool,
}
NMEA sentence output selection.

Controls which NMEA 0183 sentences are included when GPS data is output to the PC serial port. Each sentence provides different navigation data.

Fields

gga: bool

GGA – Global Positioning System Fix Data. Contains time, position, fix quality, number of satellites, HDOP, altitude, and geoid separation.

gll: bool

GLL – Geographic Position (latitude/longitude). Contains position and time with status.

gsa: bool

GSA – GPS DOP (Dilution of Precision) and Active Satellites. Contains fix mode, satellite PRNs, PDOP, HDOP, VDOP.

gsv: bool

GSV – GPS Satellites in View. Contains satellite PRN, elevation, azimuth, and SNR for each visible satellite.

rmc: bool

RMC – Recommended Minimum Specific GNSS Data. Contains time, status, position, speed, course, date, and magnetic variation. This is the most commonly used sentence.

vtg: bool

VTG – Course Over Ground and Ground Speed. Contains true/magnetic course and speed in knots/km/h.